@@ -25,6 +25,7 @@
 #include <gst/gst.h>
 #include <gst/video/video.h>
 #include <gst/video/gstvideoencoder.h>
+#include "gstencoderbitrateprofilemanager.h"
 
 #ifdef HAVE_STDINT_H
 #include <stdint.h>
@@ -34,7 +35,7 @@
  * compiler is unable to correctly do the pointer indirection for us, which
  * leads to a segfault when you try to dereference any const values provided
  * by x264.dll. See: https://bugzilla.gnome.org/show_bug.cgi?id=779249 */
-#if defined(_WIN32) && !defined(X264_API_IMPORTS)
+#if defined(_WIN32) && !defined(X264_API_IMPORTS) && !defined(GST_STATIC_COMPILATION)
 # define X264_API_IMPORTS
 #endif
 #include <x264.h>
@@ -112,6 +113,7 @@ struct _GstX264Enc
   GString *option_string; /* used by set prop */
   gint frame_packing;
   gboolean insert_vui;
+  gint nal_hrd;
 
   /* input description */
   GstVideoCodecState *input_state;
@@ -126,6 +128,8 @@ struct _GstX264Enc
 
   /* cached values to set x264_picture_t */
   gint x264_nplanes;
+
+  GstEncoderBitrateProfileManager *bitrate_manager;
 };
 
 struct _GstX264EncClass
@@ -133,7 +137,26 @@ struct _GstX264EncClass
   GstVideoEncoderClass parent_class;
 };
 
+/**
+ * GstX264EncNalHrd:
+ * @GST_X264_ENC_NAL_HRD_NONE: Specify no HRD information
+ * @GST_X264_ENC_NAL_HRD_VBR: Specify HRD information
+ * @GST_X264_ENC_NAL_HRD_CBR: Specify HRD information and pack the bitstream
+ *
+ * Signal HRD information. Required for Blu-ray streams,
+ * television broadcast and a few other specialist areas.
+ *
+ * Since: 1.26
+ */
+typedef enum
+{
+  GST_X264_ENC_NAL_HRD_NONE = 0,
+  GST_X264_ENC_NAL_HRD_VBR = 1,
+  GST_X264_ENC_NAL_HRD_CBR = 2,
+} GstX264EncNalHrd;
+
 GType gst_x264_enc_get_type (void);
+GST_ELEMENT_REGISTER_DECLARE (x264enc);
 
 G_END_DECLS
 
